@@ -49,4 +49,22 @@ def Pentagram(pentside,pentapothem,triheight):
     triangles = (pentside*triheight/2)*5
     pent = Polygon(5,pentside,pentapothem)
     area = triangles + pent
+    return area
+
+def Hexagram(hexside,hexapothem,triheight):
+    triangles = (hexside*triheight/2)*6
+    hexa = Polygon(6,hexside,hexapothem)
+    area = triangles + hexa
+    return area
+
+def Heptagram(heptside,heptapothem,triheight):
+    triangles = (heptside*triheight/2)*7
+    hept = Polygon(7,heptside,heptapothem)
+    area = triangles + hept
+    return areas
+
+def Star(shapeside,shapeapothem,points,triheight):
+    triangles = (shapeside*triheight/2)*points
+    shape = Polygon(points,shapeside,shapeapothem)
+    area = triangles + shape
     return area
\ No newline at end of file
